#
# spec file for package kakoune
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           kakoune
Version:        0.0+git.20170513
Release:        1.10
Summary:        A code editor heavily inspired by Vim
License:        Unlicense
Group:          Productivity/Text/Editors
Url:            http://kakoune.org/
Source:         %{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM -- bmwiedemann
Patch0:         reproducible.patch
BuildRequires:  asciidoc
BuildRequires:  libxslt-tools
BuildRequires:  ncurses-devel >= 5.3
# C++14 capable compiler is required
%if 0%{?suse_version} > 1320
BuildRequires:  gcc-c++ >= 5.0
BuildRequires:  libboost_regex-devel >= 1.50
%else
BuildRequires:  boost-devel >= 1.50
BuildRequires:  gcc5-c++
%endif

%description
Kakoune is a code editor heavily inspired by Vim.
It's faster as in less keystrokes, supports multiple selections and uses orthogonal design.

%prep
%setup -q -n %{name}-%{version}/src
%patch0 -p2

%build
%if 0%{?suse_version} < 1320
export CXX=g++-5
%endif
make %{?_smp_mflags} CXXFLAGS="%{optflags} -std=c++11"

%install
make %{?_smp_mflags} install PREFIX=%{buildroot}%{_prefix}
rm -rf %{buildroot}%{_datadir}/doc

%check
LANG=en_US.utf8 make %{?_smp_mflags} test

%files
%defattr(-,root,root)
%doc ../UNLICENSE ../doc/manpages/*%{ext_man}
%{_bindir}/kak
%{_datadir}/kak
%{_mandir}/man1/kak.1%{ext_man}

%changelog
* Thu May 18 2017 dziolkowski@suse.com
- Update to version 0.0+git.20170513:
  * Add column information
  * New colorscheme: desertex
  * test: Fix UTF8 compliant locale detection
  * rc: Simplify/POSIXify the `autorestore.kak` script
  * rc: POSIXify the `modeline.kak` script
  * Cleanup some tabby mess in the Makefile
  * Compile optimized and debug into different files, make `kak` a symlink
  * Fix clang warnings about uninitialized timestamp field
  * Small naming tweak
  * add rc/ocaml.kak
  * highlight hash access symbols
  * Add `RawKey` to hook completion list
  * rc: Don't print errors when no buffer backup exist
  * add racer completion for rust
  * rc: POSIX and cosmetic fixes in the `spell` script`
  * rc: add a `spell-next` command
  * src: Fix the string conversion of range faces
  * <space>, <a-space>: throw on invalid preconditions
  * Add docstring support for mappings, and use them in autoinfo
  * Make <a-space> throw on invalid index or last selection
  * Ensure main selection index is correct directly in SelectionList::remove
  * Return an optional selection in most selectors, fail rather than keep current
  * Fix indent selection respect for original selection cursor position
  * Fix tests for indent selection
  * Move object unit tests in their own subfolder
  * Refactor regex based selection code
  * Git ignore kak.opt and kak.debug
  * Refactor surround unit test code
  * Change word object selector to fail if the cursor is not on a word char
  * Remove unused AliasRegistry::flatten_aliases method
  * Add Symbol, async and await highlighting for javascript.kak
  * Document the -docstring switch of the :map command
  * Simplify AliasRegistry::remove_alias
  * escape pipe from closure in the description
  * Introduce a custom HashMap implementation along with a quick benchmark
  * Add support for HashMap options types
  * Replace uses of UnorderedMap with HashMap
  * Replace IdMap with HashMap
  * Remove temporary stats code from HashMap
  * also handle enums explicitly
  * Update Makefile
  * Expand a bit the hash map profiling code
  * Cleanup hash_map code
  * test: Remove empty test directories
  * Small code simplification
  * Collapse undo groups during an eval command
  * Try to please clang-3.5
  * doc: Add an IRC badge linking to Freenode
  * ncurses: Add a Dilbert assistant
  * Add a -debug flag to :edit to set the buffer as debug data
  * Fix crash on non utf8 files trigering highlighting of backward ranges
  * Add dilbert in the ui_options doctring
  * Change lint.kak column display to put it at the end
  * Increase modelinefmt configuration power
  * src: Align the assistant in the middle of the popup
  * src: Make the cursor character an opening delimiter
  * Add regression test for #1105
  * The canonical name for the documentation command is :doc, not :help
  * Move SelectionList::set implementation out of the header
  * Migrate to a more value based meta programming model
  * Migrate WithBitOps template specialization to with_bit_ops function
  * Remove unneeded 'valid' helper template
  * Small code tweaks regarding flags handling
  * Move enum/flags option functions to option_types.hh
  * Try to clean up option include a bit
  * Fixes some clang-tidy warning and add a few missing meta.hh include
  * Use a HashMap to store the normal mode keymap
  * Merge faces in show_whitespaces highlighter instead of replacing it
  * Try to fix clang 3.5 compilation
  * src: Introduce a `-i` suffix flag for filter backups
  * Remove some unneeded type declarations in AliasRegistry
  * Added gruvbox colorscheme
  * src: Fix the `distclean` Makefile target
  * spell.kak: preserve spelling language from :spell in :spell-replace
  * contrib: Remove `make_deb.bash`
  * Add an InsertDelete hook
  * Expose hook params regex captures in hook_param_capture_N
  * rc/ranger: use $kak_hook_param_capture_N
  * Change prompt completion to only update when idle
  * Do not disable autoinfo and autoshowcompl in non interactive context
  * ncurses: When hiding the menu, recompute the info position
  * rc: Export $TMPDIR to new `tmux` processes
  * doc: Fix the name of a now unexisting face
  * rc: Forward $TMPDIR to `iterm` subprocesses
  * src: Support the `-help` flag
  * Add support for parsing multiple modifiers in keys
  * Remove some now unneeded uses of const String& params
  * Change multi modifier key syntax to be <c-a-space> instead of <ca-space>
  * Name key '+' as plus and '-' as minus
  * Place hardware terminal cursor at the current main cursor/prompt cursor position
  * Add documentation for the set_cursor ui call in json_ui.asciidoc
  * Fix tests after addition of the set_cursor UI method
  * When not sending data to a subprocess, close its stdin
  * rc: Properly modify `tmux`'s environment with `env`
  * doc: Write a dedicated "mapping" page
  * Do not try to split non range atoms in column highlighter
  * Fix uninitialised value for cursor mode
  * Safer code for parsing commands
  * Assume filename passed to write_buffer_to_file is already parsed
  * src: Implement a `write!` command
  * Change utf8::to_next/to_previous so that they are more symetrical
  * Fix generation of empty erase changes
  * doc: Fix some issues in spelling, grammar and punctuation
  * Set stdin to /dev/null instead of closing it when we dont have data to pipe to child
  * Add noexcept specifiers to unicode and utf8 functions
  * Style tweak in highglighters.cc
  * doc: document the `X` key
  * Support appending selections to empty register
  * rc: Use $SHELL instead of spawning `bash` arbitrarily
  * Add Elixir highlighter
  * doc: Document guidelines about writing kak scripts
  * doc: Remove Debian from the list of distributions
  * Fix use of invalidated iterator in the command map on exception
  * Do not use any display information to determine where the cursor moves
  * Add a wrap highlighter
  * Introduce highlighting phases and display setup computation
  * Respect tabstop in Buffer::offset_coord
  * Make Wrap highlighter only wrap on window width.
  * Make scrolling around work more correctly with wrapping
  * Introduce a LineNumberWrapped face
  * Disable horizontal scrolling when running a WrapHighlighter
  * Detect errors while parsing flag line and handle them
  * Move passes logic to the base Highlighter class
  * Add a `-passes` switch support for the group highlighter
  * Add support for word wrapping with the -word switch to the wrap highlighter
  * Reject 0 wrap column
  * Document the wrap highlighter
  * Ensure window position line is inside buffer
  * Fix assert when wrapping a line that takes more than the full window height
  * Slight highlighting related code cleanup
  * Fix infinite loop with longer than width words in word wrap mode
  * Fix unneeded and wrong splitting of display atom during wrapping
  * Move SimpleHighlighter as an implementation detail
  * Update wrap highlighter docstring
  * Do not push a final spurious command separators when parsing commands
  * Refactor range highlighting into a struct
  * Distinguish between BufferRanges and InclusiveBufferRanges
  * Fix a few spelling errors detected by spell.kak in the README
  * Update group highlighter docstring to document the passes option
  * Rename kakrc::autoload to kakrc::autoload_directory
  * Make ref highlighter work for all highlight passes
  * Add support for the -passes option to the ref highlighter
  * Small spelling error fix
  * Use LineCount instead of int for ncurses assistant margin
  * Disable horizontal scroll offset support when wrapping
  * Use only default faces
  * fix new face documentation
  * update line-flags and flag_lines doc to reflect current status
  * misc whitespace fix in docs
  * Add the -E switch for server initialization commands
* Sun Apr 30 2017 bwiedemann@suse.com
- Add reproducible.patch to call gzip -n to make build a bit more reproducible
* Sat Feb 25 2017 mpluskal@suse.com
- Update to version 0.0+git.20170223:
  * rename commenting.kak to comment.kak
  * tweak :comment-line behaviour to comment selected lines
  * rename :comment-selection to :comment-block
  * rename line and block comments options
  * fix typo
  * remove optional value
  * fix quote convention
  * Add quote to completion characters in haskell
  * Remove hash from StringData
  * Make BufferIterator only a bidirectional iterator
  * Set commenting options for php
  * Add octothorpe to php comment highlighters
  * Remove unused Diff::posA field
  * Remove unused WindowAndSelections timestamp field
  * Make StringView and unit types trivial types
  * Detect too deep command call stack
  * Remove unneeded assignment to null in RefPtr::release
  * Fix option name in haskell.kak
  * Use iswlower instead of islower
  * Fix some uninitialized values
  * Fix infinite loop when comparing RankedMatches containing invalid utf8
  * Fix autorestore script when we have multiple restore files
  * Fix explicit insert completion menu/info not hiding
  * Warning fix in ranked_match.cc
  * Make SharedString::create take a list of StringViews
  * Rework NCurses key parsing to properly handle <a-special key>
  * Support the vim behaviour for +line syntax
  * Add some noexcept to pointer policies
  * Formatting fix
  * Tweak ranked match ordering
  * Improve POSIX sed compatibility in lint.kak
  * Fix on-key command name in README
  * support in-line comments
  * Change `n` behaviour to only select next match for main selection
  * Use <a-'> for backward rotate selection and move rotate content to <a-">
  * Also execute prompt callback when just starting
  * Document whitespace highlighter
  * Fix doc ui options and manpage
  * Adds tomorrow-night theme.
  * Make piping data into shell commands non blocking
  * Highlight c-family include paths as identifiers
  * Store shell-candidates completions in the Completion memory domain
  * Fix some bugs in non blocking pipe writing
  * Allow modifying the characters used when highlighting whitespace
  * Small layout tweak for Buffer::HistoryNode
  * Make gdb ArrayIterator python 3 compatible
  * Add Regex support in gdb pretty printing
  * Add -match-capture support for regions higlighter
  * Add proper heredoc highlighting support to sh.kak
  * Remove unneeded padding in relative line numbers highlighting
  * Fix Buffer::offset_coord that was dropping the target coordinate
  * Fix missing new line char in declare_option_cmd info
  * Add command completer for types to declare-option
  * fix regex highlighting
  * Refactor show_whitespaces a bit
  * Adds faces module and function. Renames identifier face to variable.
  * Make sure no ANSI sequences are in the data returned by `man`
  * Update outdated example in <a-"> keys doc
  * Add support for -on-change and -on-abort to prompt
  * Add elm language support
  * Fix make.kak handling of 'Entering directory' and absolute paths
  * Fix non-returning parse_key lambda
  * Fix RegisterRestorer not handling potential throws on register assign
  * Make numeric registers setable
  * Reorganize code in main.cc
  * Detect when switches are specified more than once
  * Detect when -client, -buffer or -try-client are used at the same time
  * Small naming tweak in HookManager
  * Copy the list of hooks to run before iterating on them and running them
  * pony.kak: Remove redundant BufNew/BufOpen hooks
  * Rename BufNew and BufOpen hooks to BufNewFile and BufOpenFile
  * Document backslash disabling hooks
  * Fix handling of disabled_hooks regex
  * Display an info box on startup with recent breaking changes
  * Fix hook list in commands.cc
  * Correctly handle mutation of the watcher list while iterating on them
  * Fix performance of word completion with many different selections
  * Fix overly strict backward_sorted_until
  * jedi.kak: python 3 compat fix
  * improved haskell comment regex
  * Refactor test run script
  * Try to please clang-3.5
  * Remove out of date TODO file
  * Properly wrap `kak_assert` into a do-while scope
  * Use false instead of 0 in the kak_assert do while
  * Refactor StringData and StringRegistry to remove need for purging
  * Refactor WordDB::add_words to be slightly faster
  * Slight code cleanup in utf8_iterator.hh
  * Fix support for non ascii chars in completion_extra_word_char
  * Refactor get_words to be simpler and faster
  * Tweak some character categorization function implementations
* Sun Feb  5 2017 mpluskal@suse.com
- Update boost dependencies
* Fri Jan 27 2017 mpluskal@suse.com
- Update to version 0.0+git.20170125:
  * Fix misleading wording
  * Fix escaping
  * Document +line[:column]
  * Add `gi` to go to first non-blank character on line
  * Fix crash when clearing a regex prompt with multiple selections
  * Fix shell context capture that was accessing dead parameters
  * Add a `RawKey` hook for raw user input hooking
  * Rename "shortcuts" manpage to "keys"
  * Add a quick section on key syntax in keys.asciidoc
  * More tolerant recognition of underlined titles in asciidoc highlight
  * Only restore cursor position after an append if we still have cursor > anchor
  * Fix fifo reading not handling potential errors from the read call
* Thu Nov  3 2016 mpluskal@suse.com
- Update to version 0.0+git.20161102:
  * Add to_string(long long int) overload to fix OSX compilation
  * Fix typo in write_cmd's desc
  * Use %%~~ for delimiting to avoid issues with braces in the message
  * lint-prev
  * Use same idiom as for lint-next
  * Remove since it gets overwritten by the NormalIdle hook + $kak_cursor_line will always be 1 as that runs in a temporary context for the window
  * Tweak c-family indentation logic
  * Add experimental static linking support to the makefile
  * Propagate NormalParams to user mappings
* Fri Sep 30 2016 dwaas@suse.com
- Update to version 0.0+git.20160928:
  * add ranger.kak
  * Always use quotes with sh/bash
  * disable hooks
  * fixes 'end' insertion
  * Use POSIX case and BRE
  * fixes symbol highlighting
  * highlight :: operator
  * Make idle timeout and filesystem check timeout configurable
  * Tweak zenburn theme, rely less on terminal builtin colors
  * Rewrite PerArgumentCommandCompleter to use compile time dispatching
  * More command completer code cleanup
  * Add an unmap command to remove key mappings
  * Fix select_to_reverse to correctly handle the first character of the buffer
  * Code cleanup in make_completer, use std::decay
  * Tweak Buffer::offset_coord implementation
  * Add InsertCompletionShow/InsertCompletionHide hooks
  * formatter.kak: Use sed rather than ${variable//string/replacement}
  * Add more standard GNU keywords to the makefile completion keywords
  * Add language highlighting to markdown code blocks
  * Allow dashes in target names for syntax highlighting
  * Indent after other keywords
  * Place the Makefile highlighting script alongside the `make` support script
  * Add some standard GNU targets to the Makefile
  * add ranger.kak
  * Tweak RankedMatch logic, prioritize matches that are in a single word
  * OptionDescs are const in OptionRegistry
  * Assert substr from parameter is within the string
  * Pass count to all object selectors
  * Selecting 'around' word when on spaces after word now selects next word
  * Make hook disabling work for all hooks, not only user hooks
  * Validate option names to be in [a-zA-Z0-9_]
  * Fix String::Data::reserve on big endian platforms, and document String::Data
  * Do not automatically enable ranger on directory open errors
* Thu Sep 15 2016 dwaas@suse.com
- Enabled testsuite
- Specified Requires versions in .specfile
* Thu Sep 15 2016 dwaas@suse.com
- Update to version 0.0+git.20160907:
  * Fix the directory from which the file containing a matching tag will be opened
  * Use proper buffering when reading remote messages
  * Rework client quitting and handling of remote errors
  * Fix handling of remote errors in the accepter
  * Tweak c-family indent logic
  * Small code tweak in generate_switches_doc
  * Use shell-candidates for :colorscheme completion
  * Do not let boost regex errors propagate, convert them to Kakoune errors.
  * Support kill session inside init command
  * Highlight diff in git-commit too
* Thu May  5 2016 mpluskal@suse.com
- Update to version 0.0+git.20160505:
  * add face to change whitespace colors
  * Fix splitting selecting the first buffer char when there is a match at buffer begin
  * fix whitespace label
  * Pierre CLEMENT (pierroelmito) Copyright Waiver
  * Expose a WinResize hook when a window changes size
  * Use the current client tmux session when splitting a new client
  * python.kak: restore cleaning up trailing whitespaces on newline
  * static_words def style tweak in c-family.kak
  * Restore whitespace cleanup on InsertEnd in python.kak
* Mon May  2 2016 mpluskal@suse.com
- Update to version 0.0+git.20160430:
  * Fix comparison operators in utf8_iterator and tag it as bidirectional
  * Add checked, explicit conversion from strongly typed number for size_t
  * Make use of strongly typed number to size_t conversion
  * Add missing include in file.cc
  * Add another missing include in shell_manager.cc
  * Fix test runner use of sed -r
  * Fix handling of expected to fail tests
  * Fix wrap_lines
  * Check all buffer are saved in :kill, and add :kill! to avoid that
  * Fix splitting selecting the first buffer char when there is a match at buffer begin
- Update _service
* Wed Apr 27 2016 mvetter@suse.com
- Update to latest git
* Fri Nov 13 2015 mvetter@suse.com
- Use optflags
* Fri Nov 13 2015 mvetter@suse.com
- Disable autorun of service
- Set proper version
* Thu Nov 12 2015 mvetter@suse.com
- Set PREFIX to use /usr instead of /usr/local
* Tue Nov 10 2015 mvetter@suse.com
- Creating initial package for openSUSE
  So far kakoune isnt versioned thus creating git package.
